// including the neccessary libraries for the DFPlayer to work
#include "SoftwareSerial.h"
#include "DFRobotDFPlayerMini.h"

// initialize software serial on pins 10 and 11
SoftwareSerial mySoftwareSerial(10, 11);  // RX, TX
DFRobotDFPlayerMini myDFPlayer;

// variables for force sensor pins and the 'busy' pin of the DFplayer
#define vleugelPin A0
#define buikPin A1
#define hoofdPin A2
#define busyPin 9 

// checks whether or not audio is playing (1 = not playing, 0 = playing)
int busyState;

// variables for the force sensors' values starts at 0
int vleugelReading = 0;
int buikReading = 0;
int hoofdReading = 0;

// amount of force that has to be applied on the sensors before the sound starts playinh
int minimumForce = 300; 

void setup() 
{
  // helps to check whether or not the DFplayer is initializing
  DFPlayerSetup();
}

void loop() 
{
  // reads the values of the sensors and stores them to the variables
  vleugelReading = analogRead(vleugelPin);
  buikReading = analogRead(buikPin);
  hoofdReading = analogRead(hoofdPin);
  busyState = digitalRead(busyPin);

  // plays three different audio tracks when the respective sensor is touched and busyState is 1
  PlayAudioWhenForce();
}


void DFPlayerSetup() 
{
  // serial communication with the module
  mySoftwareSerial.begin(9600);
  // initialize Arduino serial
  Serial.begin(9600);
  // check if the module is responding and if the SD card is found
  Serial.println();
  Serial.println(F("DFRobot DFPlayer Mini"));
  Serial.println(F("Initializing DFPlayer module ... Wait!"));

  if (!myDFPlayer.begin(mySoftwareSerial))
   {
    Serial.println(F("Not initialized:"));
    Serial.println(F("1. Check the DFPlayer Mini connections"));
    Serial.println(F("2. Insert an SD card"));
    while (true)
      ;
  }

  Serial.println();
  Serial.println(F("DFPlayer Mini module initialized!"));
  // initial settings
  myDFPlayer.volume(25);       // Volume 25
  myDFPlayer.EQ(0);            // Normal equalization
}

 // for debugging :)
void PrintFSRValues()
{
 
  Serial.print("vleugel sensor value:");
  Serial.println(vleugelReading);

  Serial.print("buik sensor value:");
  Serial.println(buikReading);

  Serial.print("hoofd sensor value:");
  Serial.println(hoofdReading);
}

// for debugging :)
void PrintBusyState()
{
  Serial.print("busy state is: ");
  Serial.println(busyState);
}

void PlayAudioWhenForce()
{
  if (vleugelReading > minimumForce && busyState == 1) 
  {
    myDFPlayer.play(3);
  }

  else if (buikReading > minimumForce && busyState == 1) 
  {
    myDFPlayer.play(2);
  }

  else if (hoofdReading > minimumForce && busyState == 1) 
  {
    myDFPlayer.play(1);
  }
}
